.:TSETMC:. :: معرفی گروه های صنعت

PSB is being developed by Pooya Paridel.
شركت مديريت فناوري بورس تهران
Tehran Securities Exchange Technology Management Co
معرفی گروه ها

کد گروه های صنعت | گروه های صنعت
01 | زراعت و خدمات وابسته
02 | جنگلداري و ماهيگيري
10 | استخراج زغال سنگ
11 | استخراج نفت گاز و خدمات جنبي جز اكتشاف
13 | استخراج كانه هاي فلزي
14 | استخراج ساير معادن
15 | حذف شده- فرآورده‌هاي غذايي و آشاميدني
17 | منسوجات
19 | دباغي، پرداخت چرم و ساخت انواع پاپوش
20 | محصولات چوبي
21 | محصولات كاغذي
22 | انتشار، چاپ و تكثير
23 | فراورده هاي نفتي، كك و سوخت هسته اي
24 | حذف شده-مواد و محصولات شيميايي
25 | لاستيك و پلاستيك
26 | توليد محصولات كامپيوتري الكترونيكي ونوري
27 | فلزات اساسي
28 | ساخت محصولات فلزي
29 | ماشين آلات و تجهيزات
31 | ماشين آلات و دستگاه‌هاي برقي
32 | ساخت دستگاه‌ها و وسايل ارتباطي
33 | ابزارپزشكي، اپتيكي و اندازه‌گيري
34 | خودرو و ساخت قطعات
35 | ساير تجهيزات حمل و نقل
36 | مبلمان و مصنوعات ديگر
38 | قند و شكر
39 | شركتهاي چند رشته اي صنعتي
40 | عرضه برق، گاز، بخاروآب گرم
41 | جمع آوري، تصفيه و توزيع آب
42 | محصولات غذايي و آشاميدني به جز قند و شكر
43 | مواد و محصولات دارويي
44 | محصولات شيميايي
45 | پيمانكاري صنعتي
46 | تجارت عمده فروشي به جز وسايل نقليه موتور
47 | خرده فروشي،باستثناي وسايل نقليه موتوري
49 | كاشي و سراميك
50 | تجارت عمده وخرده فروشي وسائط نقليه موتور
51 | حمل و نقل هوايي
52 | انبارداري و حمايت از فعاليتهاي حمل و نقل
53 | سيمان، آهك و گچ
54 | ساير محصولات كاني غيرفلزي
55 | هتل و رستوران
56 | سرمايه گذاريها
57 | بانكها و موسسات اعتباري
58 | ساير واسطه گريهاي مالي
59 | اوراق حق تقدم استفاده از تسهيلات مسكن
60 | حمل ونقل، انبارداري و ارتباطات
61 | حمل و نقل آبي
63 | فعاليت هاي پشتيباني و كمكي حمل و نقل
64 | مخابرات
65 | واسطه‌گري‌هاي مالي و پولي
66 | بيمه وصندوق بازنشستگي به جزتامين اجتماعي
67 | فعاليتهاي كمكي به نهادهاي مالي واسط
68 | صندوق سرمايه گذاري قابل معامله
69 | اوراق تامين مالي
70 | انبوه سازي، املاك و مستغلات
71 | فعاليت مهندسي، تجزيه، تحليل و آزمايش فني
72 | رايانه و فعاليت‌هاي وابسته به آن
73 | اطلاعات و ارتباطات
74 | خدمات فني و مهندسي
76 | اوراق بهادار مبتني بر دارايي فكري
77 | فعالبت هاي اجاره و ليزينگ
82 | فعاليت پشتيباني اجرائي اداري وحمايت كسب
90 | فعاليت هاي هنري، سرگرمي و خلاقانه
93 | فعاليتهاي فرهنگي و ورزشي
98 | گروه اوراق غيرفعال
X1 | شاخص